# Projet de développement logiciel - 4BIM INSA Lyon

    CriminAI est un logiciel destiné à générer un portrait robot afin de simplifier la tâche de reconnaissance en cas d'aggression.
    Le fonctionnement du logiciel repose sur la génération d'images par le logiciel au travers d'un algorithme d'intelligence artificielle, l'autoencodeur variationnel.
    Le principe est que la victime puisse faire une sélection des portraits les plus ressemblants à partir d'images générées par IA de manière successive dans le but de s'approcher le plus possible du visage de l'aggresseur. La méthode de génération d'images à partir de la sélection de l'utilisateur est proche d'un algorithme génétique : on applique un bruit sur les différentes caractéristiques de l'image afin de générer de nouvelles images qui sont plus proches de l'ancienne.


## Fonctionnalités

    Génération automatique de portraits robots basée sur des algorithmes d'IA.
    Interface utilisateur conviviale pour permettre à l'utilisateur de sélectionner les portraits les plus ressemblants.
    Méthode de génération d'images inspirée d'un algorithme génétique pour affiner la ressemblance avec l'agresseur.


## Comment utiliser CriminAI

    Installation : Cloner ce dépôt GitHub ou télécharger le code source.
    Configuration : Assurez-vous d'avoir les dépendances nécessaires installées (voir le tutoriel de déploiement contenant la liste des dépendances).
    Lancement : Exécutez le fichier principal criminai.py pour démarrer l'application.
    Utilisation : Suivez les instructions à l'écran pour sélectionner les portraits les plus ressemblants et affiner la génération.


## Remarques

    Ce logiciel est en cours de développement et peut contenir des bugs.
    Pour signaler un bug ou demander une fonctionnalité, veuillez ouvrir une issue sur GitHub.

## Auteurs

    Lisa Perez (@perezlisa)
    Clémence Sutter (@clemencesutter)
    Zhihan Zhong (@zhihan222)
    Matis Zouari (@matzouari)
